/*
 * Copyright (C) Cross The Road Electronics.  All rights reserved.
 * License information can be found in CTRE_LICENSE.txt
 * For support and suggestions contact support@ctr-electronics.com or file
 * an issue tracker at https://github.com/CrossTheRoadElec/Phoenix-Releases
 */
#pragma once

#include "ctre/phoenix/StatusCodes.h"
#include "ctre/phoenix6/signals/SpnEnums.hpp"
#include "ctre/phoenix6/sim/ChassisReference.hpp"
#include <units/angle.h>
#include <units/angular_velocity.h>
#include <units/voltage.h>

namespace ctre {
namespace phoenix6 {

namespace hardware {
namespace core {
	/* forward proto */
	class CoreCANdi;
}
}

namespace sim {

	/**
	 * \brief Class to control the state of a simulated hardware#CANdi.
	 */
	class CANdiSimState
	{
	private:
		int _id;

	public:
		/**
		 * \brief Creates an object to control the state of the given hardware#CANdi.
		 *
		 * \details Note the recommended method of accessing simulation features is to
		 *          use hardware#CANdi#GetSimState.
		 *
		 * \param device Device to which this simulation state is attached
		 */
		CANdiSimState(hardware::core::CoreCANdi const &device);
		/* disallow copy, allow move */
		CANdiSimState(CANdiSimState const &) = delete;
		CANdiSimState(CANdiSimState &&) = default;
		CANdiSimState &operator=(CANdiSimState const &) = delete;
		CANdiSimState &operator=(CANdiSimState &&) = default;

		/**
		 * \brief Sets the simulated supply voltage of the CANdi.
		 *
		 * \details The minimum allowed supply voltage is 4 V - values below this
		 * will be promoted to 4 V.
		 *
		 * \param volts The supply voltage in Volts
		 * \returns Status code
		 */
		ctre::phoenix::StatusCode SetSupplyVoltage(units::voltage::volt_t volts);
	};
}

}
}
